@@ -38,7 +38,7 @@ class WpSocketClient:
         """Socket connect"""
         await self.async_wait_for_disconnect()
 
-        _LOGGER.debug('connecting to server {}', {self._host})
+        _LOGGER.debug('connecting to server {}', self._host)
         try:
             asyncio.set_event_loop(self._loop)
             self._reader, self._writer = await asyncio.wait_for(
